#
# Other Sample Program
#
# Copyright(C) 2024. fireflake,inc.
#

import network
import utime
import socket 

def main():

    SSID = const('')      # 使用するWi-FiのSSID
    PASSWORD = const('')  # 使用するWi-Fiのパスワード
    
    UECS_PORT = const(16520)              # UECSのCCM送受ポート
    BROADCAST = const('255.255.255.255')  # ブロードキャストアドレス
    
    # UECS-CCMのパラメーター
    # 詳細はこちらを参照
    # https://www.uecs.jp/outline/kiyaku
    CCM_NAME = const('picow.cMC')
    CCM_ROOM = const('1')
    CCM_REGION = const('1')
    CCM_ORDER = const('1')
    CCM_PRIORITY = const('1')
    ccm_value = '100'

    # Wi-Fi接続
    wlan = network.WLAN(network.STA_IF)
    wlan.active(True)
    wlan.connect(SSID, PASSWORD)
    wlan_connect_max_wait = 30
    while wlan_connect_max_wait > 0:
        # wlanのステータスコードは下記資料を参照
        # Connecting to the Internet with Raspberry Pi Pico W - 3.6.1. Connection status codes
        # https://datasheets.raspberrypi.com/picow/connecting-to-the-internet-with-pico-w.pdf
        if wlan.status() < 0 or wlan.status() >= 3:
            break
        wlan_connect_max_wait -= 1
        print('WiFi connecting')
        utime.sleep(1)
    # Handle connection error
    if wlan.status() != 3:
        print('WiFi conn err')
    else:
        print('WiFi connected')
    
    ip_address = wlan.ifconfig()[0]
    
    # UDPで通信をする準備
    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    sock.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
    sock.bind(('',UECS_PORT))
    # CCMを作成
    ccm = '<?xml version="1.0"?><UECS ver="1.00-E10"><DATA type="' + CCM_NAME + '" room="' + CCM_ROOM  + '" region="' + CCM_REGION + '" order="' + CCM_ORDER + '" priority="' + CCM_PRIORITY + '">'+ ccm_value +'</DATA><IP>' + ip_address + '</IP></UECS>'
    send_data = ccm.encode()
    # CCMを送信
    sock.sendto(send_data,(BROADCAST,UECS_PORT))
    sock.close()
    print('sent ccm')
    
if __name__ == "__main__":
    main()
