#
# Plant Env Sensor board Sample Program
#
# Copyright(C) 2024. fireflake,inc.
#

from ssd1306 import SSD1306_I2C
from machine import I2C, Pin
import conf

class Oled:
    
    blank = ''
    
    def __init__(self,
                 i2c,
                 disp_width = 128, disp_height = 32,
                 reflesh_color = 0,
                 line1_x = 0, line1_y = 0,
                 line2_x = 0, line2_y = 8,
                 line3_x = 0, line3_y = 16,
                 line4_x = 0, line4_y = 24):
        self.reflesh_color = reflesh_color
        self.line1_x = line1_x
        self.line1_y = line1_y
        self.line2_x = line2_x
        self.line2_y = line2_y
        self.line3_x = line3_x
        self.line3_y = line3_y
        self.line4_x = line4_x
        self.line4_y = line4_y
        self.oled = SSD1306_I2C(disp_width, disp_height, i2c)
    
    # OLEDにデータ表示をさせる
    # 0～4行表示可能
    def show_data(self, line1 = blank, line2 = blank, line3 = blank, line4 = blank):
        # 新しいデータ表示前に画面をクリアする
        self.oled.fill(self.reflesh_color)
        # 1～4行のデータを表示
        self.oled.text(line1, self.line1_x, self.line1_y)
        self.oled.text(line2, self.line2_x, self.line2_y)
        self.oled.text(line3, self.line3_x, self.line3_y)
        self.oled.text(line4, self.line4_x, self.line4_y)
        self.oled.show()

def main():
    # 植物生育環境計測ボード側のI2C設定
    i2c_1 = I2C(conf.I2C1_CHANNEL, scl = Pin(conf.I2C1_SCL_PIN), sda = Pin(conf.I2C1_SDA_PIN), freq = conf.I2C1_FREQ)
    oled = Oled(i2c_1)
    # 1～3行目を表示
    oled.show_data('test1', 'test2', 'test3')

if __name__ == "__main__":
    main()

